import * as React from "react";
import { ThemeProvider, Theme, createTheme } from "@mui/material/styles";
import type { ThemeOptions } from "@mui/material/styles";
import { inputsCustomizations } from "./customizations/inputs";
import { dataDisplayCustomizations } from "./customizations/dataDisplay";
import { feedbackCustomizations } from "./customizations/feedback";
import { navigationCustomizations } from "./customizations/navigation";
import { surfacesCustomizations } from "./customizations/surfaces";
import { colorSchemes, shadows, shape } from "./themePrimitives";



interface AppThemeProps {
	children: React.ReactNode;
	disableCustomTheme?: boolean;
	themeComponents?: ThemeOptions["components"];
}

export default function AppTheme(props: AppThemeProps) {
	const { children, disableCustomTheme, themeComponents } = props;
	const theme = React.useMemo(() => {
		return disableCustomTheme
			? {}
			: createTheme({
					palette: {
						mode: "dark",
						background: {
							default: "#111111",
							paper: "#1e1e1e",
						},
						text: {
							primary: "#ffffff",
							secondary: "#b0b0b0",
						},
					},
					typography: {
						fontFamily: "Gilroy, sans-serif",
					},
					cssVariables: {
						colorSchemeSelector: "data-mui-color-scheme",
						cssVarPrefix: "template",
					},
					shadows,
					shape,
					components: {
						...inputsCustomizations,
						...dataDisplayCustomizations,
						...feedbackCustomizations,
						...navigationCustomizations,
						...surfacesCustomizations,
						...themeComponents,
					},
			  });
	}, [disableCustomTheme, themeComponents]);

	if (disableCustomTheme) {
		return <React.Fragment>{children}</React.Fragment>;
	}

	return (
		<ThemeProvider theme={theme} disableTransitionOnChange>
			{children}
		</ThemeProvider>
	);
}
